
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.14.0.post1',
    'branch_nick': 'patch-0-Release_procedure_fix',
    'revision_id': 'e8d709d6a275dd81c673edec4e1229bac0de1a99',
    'revno': 5642
}
